@@ -109,7 +109,7 @@ class FileServerConnector:
             thumbnail = dict_to_dataclass(thumbnail, FileLink)
         return original, thumbnail
 
-    async def add_file(self, file: bytes, filename: str, **kwargs) -> FileLink:
+    async def add_file(self, file: bytes, filename: str, *args, **kwargs) -> FileLink:
         warnings.warn("is deprecated, replace it with 'upload_file'", DeprecationWarning)
         return (await self.upload_file(filename, file))[0]
 
